Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(251)

Unified Diff: ui/base/layout.h

Issue 2688413007: Add display::GetDisplayNearestView (Closed)
Patch Set: add missing files Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/base/layout.h
diff --git a/ui/base/layout.h b/ui/base/layout.h
index fd2627bbc508dc171371e1f155e53998256ad8f8..eaf204644ecd91c457bd133560e1f13e70065cc3 100644
--- a/ui/base/layout.h
+++ b/ui/base/layout.h
@@ -30,8 +30,8 @@ UI_BASE_EXPORT const std::vector<ScaleFactor>& GetSupportedScaleFactors();
// little as possible.
UI_BASE_EXPORT ScaleFactor GetSupportedScaleFactor(float image_scale);
-// Returns the ScaleFactor used by |view|.
-UI_BASE_EXPORT float GetScaleFactorForNativeView(gfx::NativeView view);
+// Returns the ScaleFactor used by |window|.
+UI_BASE_EXPORT float GetScaleFactorForNativeWindow(gfx::NativeWindow window);
// Returns true if the scale passed in is the list of supported scales for
// the platform.

Powered by Google App Engine
This is Rietveld 408576698